#include <stdlib.h>
#include <stdio.h>
#include <time.h>

#include <timing.h>
#include <devices.h>

#define cMEM_BASE        0x01000000
#define cMEM_SIZE_16M    0x00080000        // 16MB (16777216 bytes) - Works OK
#define cMEM_SIZE_512K   0x00080000        // 32MB (33554432 bytes) - Works OK

#define cMEM_SIZE cMEM_SIZE_512K
static uint32_t test_count = 0;
static uint32_t test_fail_count = 0;

void main( void )
{
    unsigned short waitstate = 0;
    uint8_t buf[16] = { 0 };

    setbuf(stdout, NULL);

    printf("Starting SRAM Test for mem size: ");
    if (cMEM_SIZE == cMEM_SIZE_512K) printf("512KB - 524288 bytes\n");
    else                             printf("16MB - 16777216 bytes \n");

while(1) {
    test_count++;
    static uint32_t error_count = 0;
    static uint32_t retval = 0;

    printf("Filling memory with data ...\n");
    for(uint32_t i = 0; i < cMEM_SIZE; i += 4) {
        *(volatile unsigned int*)(cMEM_BASE + i) = i;
    }

    printf("Verifying memory ...\n");
    for(uint32_t i = 0; i < cMEM_SIZE; i += 4) {
        retval =  *((volatile unsigned int*)(cMEM_BASE + i));
        if (retval != i) {
           error_count++;
        }
    }

    if (error_count > 0) {
        printf("Test failed!\n");
        printf("     %d errors found\n", error_count);
        test_fail_count++;
    } else {
        printf("Test passed! \n");
    }
    printf("Total test count: %d \n", test_count);
    printf("    tests failed: %d \n", test_fail_count);

    printf("Starting SRAM Test for mem size: ");
    if (cMEM_SIZE == cMEM_SIZE_512K) printf("512KB \n");
    else                             printf("16MB \n");
}

}


